AQIdataframe: This function takes in data, specifically the name of a csv...

Description Usage Arguments Value

View source: R/build_dataframes.R

Description

This function takes in data, specifically the name of a csv file with timestamps, ChannelA, ChannelB, humidity, latitude and longitude It then cleans the data frame and returns AQI values.

Usage

1

Arguments

data,

specifically the name of a csv file

Value

it returns a dataframe with hourly time, AQI, humidity, latitude and longitude


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.