Return identifiers for all available projects whose matrices have been prepared for analysis.

AllProjects(indices = NULL, sort = TRUE)

Arguments

indices

Optional integer vector specifying which projects to return (after sorting).

sort

Logical; whether to sort project IDs numerically.

Value

Character vector of project identifiers.