ComparisonTrees samples trees from the posterior; then drops and relabel leaves until the taxon set matches that in the corresponding well corroborated trees

ComparisonTrees(scriptID, pID)

Arguments

scriptID

Character specifying the script to run

pID

Character specifying the project identifier to analyse