Store SSH credentials for this project with file.edit(".Renviron"), or globally with file.edit("~/.Renviron").

ConnectSSH()

Value

ConnectSSH() is called for its side effect of launching an SSH session.

Details

Set sshLogin=username@server.url, sshKey=path/to/keyfile and sshPass=keepFilePassword. Restart R for these to take effect.

See also

To store the session for future use, see SshSession().