Existing results Read results that have already been cached using UpdateRecords().

ExistingResults(pID, scriptID, checkRemote = FALSE)

Arguments

pID

Character specifying the project identifier to analyse

scriptID

Character specifying the script to run

`checkRemote`

Logical. If results do not exist locally, should we attempt to retrieve them from the remote server?