Create a slurm job Constructs and submits a slurm job to complete an analysis

MakeSlurm(
  pID,
  scriptID,
  ml = FALSE,
  ess = EssTarget(pID, scriptID),
  replace = FALSE,
  generous = TRUE
)

Arguments

pID

Character specifying the project identifier to analyse

scriptID

Character specifying the script to run

ml

Logical; if true, calculate the marginal likelihood; if false, run MCMCMC analysis

ess

Numeric: Estimated sample size to attempt to obtain

replace

Logical: should a corresponding job be cancelled in order to run this job instead?