Difference between marginal likelihood estimates obtained by stepping stone and path sampling analyses.

MarginalDiffs(projects, models)

Arguments

projects

Character vector listing project identifiers to evaluate.

models

Character vector specifying models to evaluate.

Value

MarginalDiffs() returns a matrix specifying the difference (in log units) between the stepping stone and path sampling estimates of the marginal likelihood.