Set the paths in which files should be stored using options("ntOutDir" = "path/to/analytical/outputs"), options("ntSlurmDir" = "path/to/slurm/files") options("ntRBScriptDir" = "path/to/RevBayes/scripts") and options("ntRepoDir" = "path/where/repos/will/be/checked/out/to")

OutputDir()

RepoDir()

SlurmDir()

RemoteDir()

RBScriptDir()

Details

Set options("ntRemoteDir" = "path/on/remote/server") to the directory on the remote server to which the neotrans repository is checked out.

These will default respectively to:

  • OutputDir(): the package's installation location

  • SlurmDir(): the folder "slurm" in the package's installation location.

  • RepoDir(): a directory revbayes-repos placed within the directory into which the package is installed.

  • RemoteDir(): /nobackup/$USER