Output a plot to file or graphics device

OutputPlot(figName, width, height, Plot)

Arguments

figName

Figure filename (without suffix)

width, height

Figure dimensions in inches

Plot

function to execute, which should produce a plot.

Value

OutputPlot() is called for its side-effecits: it launches a new device of the type specified by getOption("ntOutput") (supported: "png", "pdf", "device", where the latter is the default and plots to the active graphics device).