Constructs the path to the .rda file storing results of parsimony and Bayesian evaluation for a given project, script, and parameter combination.

ParsEvalFile(pID, scriptID = NULL, nPars, nBayes)

Arguments

pID

Character specifying the project identifier to analyse

scriptID

Character specifying the script to run

nPars, nBayes

Integer counts of parsimony and Bayesian replicates.

Value

Character string giving .rda file path.