Returns the path to the .rds file containing parsimony scores of sampled trees for a given project and script. Scores are generated and written to this path by PosteriorTreeSteps() via TreeSearch().

ParsimonyFile(pID, scriptID)

Arguments

pID

Character specifying the project identifier to analyse

scriptID

Character specifying the script to run

Value

Character string giving .rds file path.