Computes the proportional change in precision between two values, depending on whether improvement is expected to correspond to an increase or decrease relative to a baseline.

PrecisionIncrease(x, baseline = -Inf, improvement = Inf)

Arguments

x

Numeric vector of length two, giving the values to compare.

baseline

Numeric scalar giving the reference baseline (default -Inf).

improvement

Numeric scalar giving the direction of expected improvement (default Inf).

Value

'PrecisionIncrease()' returns a single numeric value giving the proportional improvement in precision, or NA_real_ if x is NULL.

See also

Other tree-comparisons: Dispersion(), TreeDistances(), TreeLengths()