Start ssh session with remote server

SshSession()

Value

SshSession() is called for its side-effect of beginning a new ssh session and registering this in the package environment for future calls to the remote.