If new MCMCMC result are available, compute and cache convergence statistics.

UpdateRecords(
  pID,
  scriptID,
  searchRemote = FALSE,
  forgetCache = FALSE,
  makeSlurm = FALSE
)

Arguments

searchRemote

Logical: if git fetch does not retrieve new results, should we check for uncommitted changes on the remote host?

forgetCache

Logical: if no new results are found, should we recalculate cached statistics anyway?

makeSlurm

Logical: If existing results have not yet converged or are not available, should we queue a continuation run?

Details

Parameters and trees are written to cache using UpdateResults(), called from within this function.