cleanAQMD: This function takess in data, specifically the name of a read...

Description Usage Arguments Value

View source: R/build_dataframes.R

Description

This function takess in data, specifically the name of a read csv file with timestamps, PM2.5, humidity, latitude and longitude It then cleans the changes the timestamps so that they match the timstamps of the purple air data.

Usage

1

Arguments

data,

specifically the name of a csv file

Value

it returns a dataframe with hourly time (in the format of Ymd hms), PM2.5, humidity, latitude and longitude


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.