cleanPA: Clean Raw Sensor Data

Description Usage Arguments Value

View source: R/build_dataframes.R

Description

This function cleans up the raw readings from the PA sensors and sets up a data frame. It assumes that the data has the columns c('timestamp', "channelAPm25", "channelBPm25", "humidity", "latitude", "longitude") in that order. It also uses an EPA correction factor for PurpleAir sensors. Any readings with faulty channel A/B values will be dropped

Usage

1

Arguments

data

a .csv of PurpleAir sensor data from the CEHAT website

Value

a dataframe of the full PurpleAir sensor data, with corrected timezone and combined channels


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.