compareDataDF: This function takes in a data frame of values with columns...

Description Usage Arguments Value

View source: R/build_dataframes.R

Description

This function takes in a data frame of values with columns timestamp, otherCityPM, southGatePM, and PM2.5. It also takes in the name of the city returns the results after conducting t-tests on them

Usage

1
compareDataDF(ourData, nameOfCity)

Arguments

two

arrays of data with matching days and the name of the non-South Gate city

Value

it returns the t test results of the data sets


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.