compareSensors: Above/Below Median

Description Usage Arguments Value

View source: R/build_dataframes.R

Description

This reports which sensors were down and on which days that they went

Usage

1
compareSensors(data, type = c("a", "b"), new)

Arguments

data

output of the hourlyPA function (a dataframe of hourly PurpleAir sensor data)

type

a single-character string indicating whether values above or below the median should be returned

new

a boolean specifying if you are using the new data format (in which case you put TRUE) or the old data format (in which case you put FALSE)

Value

a dataframe that details how many readings are above/below the median for each sensor, along with that sensors total readings


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.