dailySG: Daily Summary Data for South Gate

Description Usage Arguments Value

View source: R/build_dataframes.R

Description

This function aggregates data (output from the hourlyPA/cleanPA function) by hour for mean, median, max, min, and count of sensors It assumes that the data has the columns 'timestamp', 'day', 'hour' 'PM2.5.

Usage

1

Arguments

data

the output dataframe of the hourlyPA or cleanPA functions

Value

a dataframe of the holistic South Gate data, including weighted sensor averages, sensor median, the max, and the min, and active count.


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.