distance: This function takes in four parameters:...

Description Usage Arguments Value

View source: R/distance.R

Description

This function takes in four parameters: lat_1,long_1,lat_2,long_2. It then calculates the distance between these two locations using the Haversine formula.

Usage

1
distance(lat_1, long_1, lat_2, long_2)

Arguments

latitude

of the first location, longitude of the first location, latitude of the second location, longitude of the second location

Value

it returns the distance between these locations in miles


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.