Do two estimates differ by a noteworthy amount?

.OutwithError(x, err, eps = epsBF)

Arguments

x

Value to compare; typically a Bayes Factor giving difference in estimated marginal likelihoods of two models

err

Standard error of comparison, perhaps computed using .DiffErr()

eps

Numeric; errors smaller than eps are not deemed noteworthy.

Value

.OutwithError() returns a logical vector stating whether each element in x is greather than the corresponding eps and err