accuracy is a list of nTip vectors (one per tip); c() concatenates the two runs' values for the same tip.R/simFuncsImp.R
dot-PoolRuns.RdPool runs within each replicate, then summarise per replicate
Each cell of accuracy is a list of nTip vectors (one per tip);
c() concatenates the two runs' values for the same tip.
.PoolRuns(r1, r2)