downSensors: Down Sensors?

Description Usage Arguments Value

View source: R/build_dataframes.R

Description

This reports which sensors were down and on which days that they went down. This

Usage

1

Arguments

data

a dataframe of hourly PurpleAir sensor data from the CEHAT website

new

a boolean specifying if you are using the new data format (in which case you put TRUE) or the old data format (in which case you put FALSE)

Value

a list object including the logical dataframe showing when sensors went down and the corresponding numerical representation of this, which counts the days


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.