gettingCityName: This function takes in a read csv file from AQMD and returns...

Description Usage Arguments Value

View source: R/gettingCityName.R

Description

This function takes in a read csv file from AQMD and returns the name of the city that the data is about

Usage

1

Arguments

a

csv file

Value

it returns the name that the data set is about.


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.