highslows: Collect Highs and Lows for PM2.5 per day

Description Usage Arguments Value

View source: R/build_dataframes.R

Description

This function collects the daily high and low values of PM2.5 for each sensor into a dataframe. It assumes that the data has the columns 'timestamp' and 'longitude'. Any identical readings of duplicate type will be dropped

Usage

1

Arguments

data

a dataframe of hourly PurpleAir sensor data from the CEHAT website

Value

a dataframe of the highs and lows of PurpleAir sensor data, organized by sensor


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.