hourlyPA: Aggregate Data by Hour

Description Usage Arguments Value

View source: R/build_dataframes.R

Description

This function aggregates the frequent readings from each sensor and averages them by hour. It assumes that the data has the columns 'timestamp' and 'longitude'. It also uses an EPA correction factor for PurpleAir sensors. Any readings with faulty channel A/B values will be dropped

Usage

1

Arguments

data

a CLEANED dataframe of PurpleAir sensor data a boolean specifying if we are using the new

new

a boolean specifying if we are using the new data (in which case you put TRUE) or the old data (in which case you put FALSE)

Value

a dataframe of the hourly PA sensor data, with sensor names, days of the week, hour, and time of day


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.