krigePA: Kriging Function

Description Usage Arguments Value

View source: R/interpolation.R

Description

This uses the automap package to conduct interpolation analysis on ONE HOUR of air quality data It assumes that the data is the output of the function "hourlyPA". There is no alternative for this

Usage

1

Arguments

data

output of hourlyPA function, or air quality data organized by 1-hour timestamps

time

a character object of forrmat "yyyy-mm-dd hh:00:00"

Value

the interpolation result: three objects of similar format: the input grid populated by values of predictions, variance, or standard deviation


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.