Description Usage Arguments Value
View source: R/visualizations.R
This function creates a lollipop chart visualization for PurpleAir high/low sensor data.
1 |
data |
a .csv of PurpleAir high/low sensor data from the CEHAT website |
sensor |
which sensor you want to view |
a lollipop ggplot2 chart of daily high and low values per sensor for a given time period
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.