matchingDays: This function takes in cleaned purple air data, a dataframe...

Description Usage Arguments Value

View source: R/build_dataframes.R

Description

This function takes in cleaned purple air data, a dataframe with timestamps, PM2.5, humidity, latitude and longitude, and a AQMD csv files. It then combines these two files to make a dataframe with matching days.

Usage

1
matchingDays(SGdata, otherCitydata)

Arguments

SGdata

and otherCitydata, two csv files

Value

it returns a dataframe with matching days


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.