newCleanPA: This function cleans up the raw readings from the PA sensors...

Description Usage Arguments Value

View source: R/build_dataframes.R

Description

This function cleans up the raw readings from the PA sensors and sets up a data frame. It assumes that the data has the columns c('Timestamp', "Names", "PM2.5", "Percent.Difference","Humidity", "Latitude", "Longitude") in that order. It drops negative PM2.5 values and cleans the time to match LA time.

Usage

1

Arguments

data

a .csv of PurpleAir sensor data from the CEHAT website

Value

a dataframe of the full PurpleAir sensor data, with corrected timezone and PM2.5 levels


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.