overEPA: This function takes in a data frame of values from one sensor...

Description Usage Arguments Value

View source: R/build_dataframes.R

Description

This function takes in a data frame of values from one sensor and returns a dataframe of the days where the PM2.5 values surpass the EPA threshold.

Usage

1
overEPA(ourData)

Arguments

a

dataframe of values from one sensor and the name of the PM2.5 category

Value

a dataframe of the days where the PM2.5 values surpass the EPA threshold.


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.