overEPA_hist: This function takes in a data frame of values that is cleaned...

Description Usage Arguments Value

View source: R/build_dataframes.R

Description

This function takes in a data frame of values that is cleaned by overEPA and the number of days that we have sensor data for (not number of days that are over EPA threshold), and returns a dataframe that fits in the histogram function

Usage

1
overEPA_hist(daysOver, numOfDays)

Arguments

a

dataframe of values from one sensor after being cleaned by overEPA

Value

a dataframe that fits in the histogram function


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.