sensitiveLocations: Sensitive Locations

Description Usage Arguments Value

View source: R/build_dataframes.R

Description

Sensitive Locations

Usage

1

Arguments

the

input is the data that is outputted in the PAhourly function and a time a character object of forrmat "yyyy-mm-dd hh:00:00"

Value

a dataframe that contains sensitive locations and their locations


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.