southgate: Add a polygon map of South Gate

Description Usage Value

View source: R/maps.R

Description

This function produces a line drawing of the city of South Gate, classed as a Spatial Polygons Data Frame

Usage

1

Value

an easily plot-able polygon of South Gate, of the class Spatial Polygons DF


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.