This function produces a grid of the city of South Gate, classed as a Spatial Pixels Data Frame
1 |
an easily plot-able grid of South Gate, of the class Spatial Pixels DF; useful for kriging
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.