toRad: This function takes in one parameter:degrees. It then...

Description Usage Arguments Value

View source: R/distance.R

Description

This function takes in one parameter:degrees. It then calculates the radian of that specified value.

Usage

1
toRad(degrees)

Arguments

degrees

that you want to convert to radian

Value

it returns the radian value of that degree value


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.