ttests: This function takes in two arrays of data (with corresponding...

Description Usage Arguments Value

View source: R/ttests.R

Description

This function takes in two arrays of data (with corresponding days) and the city name (the non-south gate city name) and returns the results after conducting t-tests on them

Usage

1
ttests(otherCityData, SGdata, cityName)

Arguments

two

arrays of data with matching days and the name of the non-South Gate city

Value

it returns the t test results of the data sets


CEHAT-Clinic/analysis documentation built on Dec. 17, 2021, 12:54 p.m.