Description Usage Arguments Value
View source: R/build_dataframes.R
This function takes in data, specifically the name of a csv file with timestamps, ChannelA, ChannelB, humidity, latitude and longitude It then cleans the data frame and returns AQI values.
1 |
data, |
specifically the name of a csv file |
it returns a dataframe with hourly time, AQI, humidity, latitude and longitude
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.