R/FilePaths.R
AllProjects.Rd
Return identifiers for all available projects whose matrices have been prepared for analysis.
AllProjects(indices = NULL, sort = TRUE)
Optional integer vector specifying which projects to return (after sorting).
Logical; whether to sort project IDs numerically.
Character vector of project identifiers.