Calculates the effective sample size (ESS) for one or more MCMC chains, discarding an initial burn-in.
ESS(values, burnin, Summarize = min)ESS() returns a numeric vector of effective sample sizes for each parameter.
When multiple runs are supplied, the summarized ESS across runs is returned.
If a list of chains is supplied, ESS() applies the calculation to each chain
and summarizes results across chains using the specified summary function.
The effective sample size is estimated using ess from
the mcmcse package. Burn-in samples are removed using
BurnOff() prior to calculation.
PSRF() for potential scale reduction diagnostics.