UpdateRecords()
R/CheckComplete.R
ExistingResults.Rd
Existing results Read results that have already been cached using UpdateRecords().
ExistingResults(pID, scriptID, checkRemote = FALSE)
Character specifying the project identifier to analyse
Character specifying the script to run
Logical. If results do not exist locally, should we attempt to retrieve them from the remote server?