R/MakeSlurm.R
MakeSlurm.RdCreate a slurm job Constructs and submits a slurm job to complete an analysis
MakeSlurm(
pID,
scriptID,
ml = FALSE,
ess = EssTarget(pID, scriptID),
replace = FALSE,
generous = TRUE
)Character specifying the project identifier to analyse
Character specifying the script to run
Logical; if true, calculate the marginal likelihood; if false, run MCMCMC analysis
Numeric: Estimated sample size to attempt to obtain
Logical: should a corresponding job be cancelled in order to run this job instead?