R/CheckComplete.R
MarginalDiffs.RdDifference between marginal likelihood estimates obtained by stepping stone and path sampling analyses.
MarginalDiffs(projects, models)MarginalDiffs() returns a matrix specifying the difference
(in log units) between the stepping stone and path sampling estimates of the
marginal likelihood.