Bayes factor support for each model, relative to best fitting
ModelBF(marginals, models)
Arguments
- marginals
Matrix specifying marginal likelihood of each model (rows)
for each dataset (columns)
- models
vector identifying the rows of marginals to be considered