Computes the proportional change in precision between two values, depending on whether improvement is expected to correspond to an increase or decrease relative to a baseline.
PrecisionIncrease(x, baseline = -Inf, improvement = Inf)'PrecisionIncrease()' returns a single numeric value giving the proportional
improvement in precision, or NA_real_ if x is NULL.
Other tree-comparisons:
Dispersion(),
TreeDistances(),
TreeLengths()