Necessary because some files became corrupted: my suspicion is that
continuing a run on RB<1.4 with RB>1.4 causes an issue when no .heat.ckp
files are found.
RewindRepo(pID, scriptID, lastGoodID)
Arguments
- pID
Character specifying the project identifier to analyse
- scriptID
Character specifying the script to run
- lastGoodID
Git identifier denoting (first characters of) last good
commit ID. A blank entry will return.
"n" will delete relevant files and enqueue a fresh analysis.
Details
Updates the git repo, deletes cache files, and runs UpdateRecords().