SpindlePlot() creates a histogram arranged analogously to a violin plot
SpindlePlot(
x,
nBin = 20,
width = 1,
xlab = "",
log = FALSE,
Behind = function() {
},
clip,
weights = NULL,
...
)data.frame or matrix in which columns correspond to distinct values to plot.
Integer giving number of bins
Numeric giving relative width of each spindle
Logical specifying whether to log-transform the y axis
Function to be executed before drawing the spindles
Numeric specifying weight of each observation, for a weighted mean.
Additional arguments to plot()
Vector giving colour for each spindle