This function compares two sets of posterior trees for a given project ID and
models, computing a normalized Clustering Information distance using the
TreeDist package. If distance results already exist, they are loaded
from disk. Otherwise, the function attempts to generate missing tree samples
using MakeSlurm(), and if both are available, it computes and stores the
distance matrix.
TreeDistances(pID, model1, model2)'TreeDistances()' returns a matrix of pairwise tree distances (as computed by
ClusteringInfoDistance) if both model samples are
available. If any tree sample is missing and a job is submitted via
MakeSlurm(), the function returns NULL.
Other tree-comparisons:
Dispersion(),
PrecisionIncrease(),
TreeLengths()