Reads the tree sample corresponding to a given project and script identifier,
and returns the total branch length for each tree. If the sample file does
not exist, a MakeSlurm() job is initiated to generate it.
TreeLengths(pID, scriptID)'TreeLengths()' returns a numeric vector giving the total branch length of
each tree in the sample. If the tree file is missing, it returns
NULL after initiating a MakeSlurm() job.
Other tree-comparisons:
Dispersion(),
PrecisionIncrease(),
TreeDistances()