If new MCMCMC result are available, compute and cache convergence statistics.
UpdateRecords(
pID,
scriptID,
searchRemote = FALSE,
forgetCache = FALSE,
makeSlurm = FALSE
)Logical: if git fetch does not retrieve new results,
should we check for uncommitted changes on the remote host?
Logical: if no new results are found, should we recalculate cached statistics anyway?
Logical: If existing results have not yet converged or are not available, should we queue a continuation run?
Parameters and trees are written to cache using UpdateResults(), called
from within this function.