Description Usage Arguments Value
View source: R/build_dataframes.R
This function takess in data, specifically the name of a read csv file with timestamps, PM2.5, humidity, latitude and longitude It then cleans the changes the timestamps so that they match the timstamps of the purple air data.
1 |
data, |
specifically the name of a csv file |
it returns a dataframe with hourly time (in the format of Ymd hms), PM2.5, humidity, latitude and longitude
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.