Description Usage Arguments Value
View source: R/build_dataframes.R
This function takes in a data frame of values with columns timestamp, otherCityPM, southGatePM, and PM2.5. It also takes in the name of the city returns the results after conducting t-tests on them
1 | compareDataDF(ourData, nameOfCity)
|
two |
arrays of data with matching days and the name of the non-South Gate city |
it returns the t test results of the data sets
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.