Description Usage Arguments Value
View source: R/build_dataframes.R
This reports which sensors were down and on which days that they went
1 | compareSensors(data, type = c("a", "b"), new)
|
data |
output of the hourlyPA function (a dataframe of hourly PurpleAir sensor data) |
type |
a single-character string indicating whether values above or below the median should be returned |
new |
a boolean specifying if you are using the new data format (in which case you put TRUE) or the old data format (in which case you put FALSE) |
a dataframe that details how many readings are above/below the median for each sensor, along with that sensors total readings
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.