Description Usage Arguments Value
View source: R/build_dataframes.R
This function aggregates data (output from the hourlyPA/cleanPA function) by hour for mean, median, max, min, and count of sensors It assumes that the data has the columns 'timestamp', 'day', 'hour' 'PM2.5.
1 |
data |
the output dataframe of the hourlyPA or cleanPA functions |
a dataframe of the holistic South Gate data, including weighted sensor averages, sensor median, the max, and the min, and active count.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.