Description Usage Arguments Value
This function takes in four parameters: lat_1,long_1,lat_2,long_2. It then calculates the distance between these two locations using the Haversine formula.
1 | distance(lat_1, long_1, lat_2, long_2)
|
latitude |
of the first location, longitude of the first location, latitude of the second location, longitude of the second location |
it returns the distance between these locations in miles
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.