R/Analyses.R
dot-DiffErr.Rd
The error associated with a difference can be computed from the error associated with each input variable
.DiffErr(err1, err2)
Numeric vectors giving errors to be combined.
.DiffErr() returns a vector detailing the combined error for each element in err1.
.DiffErr()
err1