Description Usage Arguments Value
View source: R/build_dataframes.R
This reports which sensors were down and on which days that they went down. This
1 |
data |
a dataframe of hourly PurpleAir sensor data from the CEHAT website |
new |
a boolean specifying if you are using the new data format (in which case you put TRUE) or the old data format (in which case you put FALSE) |
a list object including the logical dataframe showing when sensors went down and the corresponding numerical representation of this, which counts the days
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.