Description Usage Arguments Value
View source: R/gettingCityName.R
This function takes in a read csv file from AQMD and returns the name of the city that the data is about
1 |
a |
csv file |
it returns the name that the data set is about.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.