Description Usage Arguments Value
View source: R/build_dataframes.R
This function collects the daily high and low values of PM2.5 for each sensor into a dataframe. It assumes that the data has the columns 'timestamp' and 'longitude'. Any identical readings of duplicate type will be dropped
1 |
data |
a dataframe of hourly PurpleAir sensor data from the CEHAT website |
a dataframe of the highs and lows of PurpleAir sensor data, organized by sensor
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.