Description Usage Arguments Value
View source: R/interpolation.R
This uses the automap package to conduct interpolation analysis on ONE HOUR of air quality data It assumes that the data is the output of the function "hourlyPA". There is no alternative for this
1 |
data |
output of hourlyPA function, or air quality data organized by 1-hour timestamps |
time |
a character object of forrmat "yyyy-mm-dd hh:00:00" |
the interpolation result: three objects of similar format: the input grid populated by values of predictions, variance, or standard deviation
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.