Description Usage Arguments Value
View source: R/build_dataframes.R
This function takes in cleaned purple air data, a dataframe with timestamps, PM2.5, humidity, latitude and longitude, and a AQMD csv files. It then combines these two files to make a dataframe with matching days.
1 | matchingDays(SGdata, otherCitydata)
|
SGdata |
and otherCitydata, two csv files |
it returns a dataframe with matching days
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.