Description Usage Arguments Value
View source: R/build_dataframes.R
This function cleans up the raw readings from the PA sensors and sets up a data frame. It assumes that the data has the columns c('Timestamp', "Names", "PM2.5", "Percent.Difference","Humidity", "Latitude", "Longitude") in that order. It drops negative PM2.5 values and cleans the time to match LA time.
1 |
data |
a .csv of PurpleAir sensor data from the CEHAT website |
a dataframe of the full PurpleAir sensor data, with corrected timezone and PM2.5 levels
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.