Description Usage Arguments Value
View source: R/build_dataframes.R
This function takes in a data frame of values from one sensor and returns a dataframe of the days where the PM2.5 values surpass the EPA threshold.
1 | overEPA(ourData)
|
a |
dataframe of values from one sensor and the name of the PM2.5 category |
a dataframe of the days where the PM2.5 values surpass the EPA threshold.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.