This function produces a line drawing of the city of South Gate, classed as a Spatial Polygons Data Frame
1 |
an easily plot-able polygon of South Gate, of the class Spatial Polygons DF
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.