Description Usage Arguments Value
This function takes in one parameter:degrees. It then calculates the radian of that specified value.
1 | toRad(degrees)
|
degrees |
that you want to convert to radian |
it returns the radian value of that degree value
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.