Description Usage Arguments Value
This function takes in two arrays of data (with corresponding days) and the city name (the non-south gate city name) and returns the results after conducting t-tests on them
1 | ttests(otherCityData, SGdata, cityName)
|
two |
arrays of data with matching days and the name of the non-South Gate city |
it returns the t test results of the data sets
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.